@@ -78,7 +78,16 @@ class ClBuilderMenuAction(Action):
          'method': 'Builder.setup_package("sys-boot/grub")',
          'condition': lambda Get: (Get('os_root_type_ext') in RootType.HDDs and
                                    Get('builder.cl_builder_livemenu_path') !=
-                                   Get('builder.cl_livemenu_path'))
+                                   Get('builder.cl_livemenu_path') and
+                                   Get('builder.cl_builder_livemenu_path'))
+         },
+        {'name': 'grub:setup_grub_empty',
+         'message': __("Disabling the Live HDD menu from grub"),
+         'method': 'Builder.setup_package("sys-boot/grub")',
+         'condition': lambda Get: (Get('os_root_type_ext') in RootType.HDDs and
+                                   Get('builder.cl_builder_livemenu_path') !=
+                                   Get('builder.cl_livemenu_path') and
+                                   not Get('builder.cl_builder_livemenu_path'))
          },
         {'name': 'flash:mount_flash',
          'method': 'Builder.remount_rw(cl_builder_flash_path)',
